Learn R Programming

gsDesignTune (version 0.1.0)

gsSurvTune: Create a tune job for gsDesign::gsSurv()

Description

gsSurvTune() is a drop-in replacement for gsDesign::gsSurv() that returns a tune job object instead of immediately running a single design.

Usage

gsSurvTune(..., upper = NULL, lower = NULL)

Value

A GSDTuneJob R6 object.

Arguments

...

Arguments to gsDesign::gsSurv(). Any argument can be replaced by a tune_*() specification.

upper, lower

Optional spending specifications provided as SpendingSpec or SpendingFamily. When supplied, these are translated to the underlying (sfu, sfupar) / (sfl, sflpar) arguments.

Details

Any argument can be replaced by a tuning specification created by tune_*(). Use SpendingSpec / SpendingFamily via upper= and lower= for dependency-aware spending function tuning.

Examples

Run this code
job <- gsSurvTune(
  k = 3,
  test.type = 4,
  hr = tune_values(list(0.6, 0.7))
)
# \donttest{
job$run(strategy = "grid", parallel = FALSE, seed = 1)
utils::head(job$results())
# }

Run the code above in your browser using DataLab