powered by
tune_dep() defines candidates for one argument as a function of other arguments.
tune_dep()
tune_dep(depends_on, map)
A gstune_spec object.
gstune_spec
Character vector of argument names this specification depends on.
A function returning either a tune_*() specification or a fixed value. The function should have arguments matching depends_on (or use ...).
tune_*()
depends_on
...
# sfupar depends on sfu tune_dep( depends_on = "sfu", map = function(sfu) { if (identical(sfu, gsDesign::sfLDOF)) tune_fixed(0) else tune_seq(-4, 4, 9) } )
Run the code above in your browser using DataLab